@@ -69,6 +69,18 @@ class IssueBoundary:
                 and span._.suggestions[0] == ""
         )
 
+    @staticmethod
+    def _would_cause_double_comma(span: Span) -> bool:
+        return (
+                (
+                        span.doc.text[span.start_char - 1] == "," or
+                        (span.doc.text[span.start_char - 1] == " " and span.doc.text[span.start_char - 2] == ",")
+                )
+                and span.doc.text[span.end_char] == ","
+                and len(span._.suggestions) > 0
+                and span._.suggestions[0] == ""
+        )
+
     @staticmethod
     def _is_comma_replacement_that_could_be_deletion(span: Span) -> bool:
         return (
@@ -131,6 +143,10 @@ class IssueBoundary:
             # don't allow this
             if "," in span._.suggestions:
                 span._.suggestions.remove(",")
+                # now maybe so suggestions are left,
+                # so add DELETE operation (i.e. suggest replacement with "")
+                if not len(span._.suggestions):
+                    span._.suggestions.append("")
         return span
 
     @staticmethod
@@ -146,6 +162,9 @@ class IssueBoundary:
 
             span = IssueBoundary._sanity_check(span)
 
+            if IssueBoundary._would_cause_double_comma(span):
+                span.end_char += 1
+
             if IssueBoundary._would_cause_double_space(span):
                 # double space issue, extending issue back one character
                 span.start_char -= 1
